@@ -29,6 +29,9 @@ class AppConfig:
         #: ClowdApp deployment configuration for Clowder enabled apps.
         self.logging = None
 
+        #: ClowdApp deployment configuration for Clowder enabled apps.
+        self.metadata = None
+
         #: ClowdApp deployment configuration for Clowder enabled apps.
         self.kafka = None
 
@@ -68,6 +71,8 @@ class AppConfig:
 
         obj.logging = LoggingConfig.dictToObject(dict.get('logging', None))
 
+        obj.metadata = AppMetadata.dictToObject(dict.get('metadata', None))
+
         obj.kafka = KafkaConfig.dictToObject(dict.get('kafka', None))
 
         obj.database = DatabaseConfig.dictToObject(dict.get('database', None))
@@ -114,6 +119,28 @@ class LoggingConfig:
         return obj
 
 
+class AppMetadata:
+    """ Arbitrary metadata pertaining to the application application
+    """
+
+    def __init__(self):
+
+        #: Arbitrary metadata pertaining to the application application
+        self.deployments = []
+
+    @classmethod
+    def dictToObject(cls, dict):
+        if dict is None:
+            return None
+        obj = cls()
+
+        arrayDeployments = dict.get('deployments', [])
+        for elemDeployments in arrayDeployments:
+            obj.deployments.append(
+                DeploymentMetadata.dictToObject(elemDeployments))
+        return obj
+
+
 class KafkaConfig:
     """ Kafka Configuration
     """
@@ -299,6 +326,9 @@ class FeatureFlagsConfig:
         #: Feature Flags Configuration
         self.clientAccessToken = None
 
+        #: Feature Flags Configuration
+        self.scheme = None
+
     @classmethod
     def dictToObject(cls, dict):
         if dict is None:
@@ -310,6 +340,8 @@ class FeatureFlagsConfig:
         obj.port = dict.get('port', None)
 
         obj.clientAccessToken = dict.get('clientAccessToken', None)
+
+        obj.scheme = FeatureFlagsConfigSchemeEnum.valueForString(dict.get('scheme', None))
         return obj
 
 
@@ -415,6 +447,30 @@ class CloudWatchConfig:
         return obj
 
 
+class DeploymentMetadata:
+    """ Deployment Metadata
+    """
+
+    def __init__(self):
+
+        #: Deployment Metadata
+        self.name = None
+
+        #: Deployment Metadata
+        self.image = None
+
+    @classmethod
+    def dictToObject(cls, dict):
+        if dict is None:
+            return None
+        obj = cls()
+
+        obj.name = dict.get('name', None)
+
+        obj.image = dict.get('image', None)
+        return obj
+
+
 class BrokerConfig:
     """ Broker Configuration
     """
@@ -570,3 +626,32 @@ class ObjectStoreBucket:
         return obj
 
 
+class FeatureFlagsConfigSchemeEnum(Enum):
+    HTTP = 'http'
+    HTTPS = 'https'
+
+    @classmethod
+    def valueForString(cls, stringValue):
+        lowerStringValue = stringValue.lower() if stringValue is not None else None
+        if lowerStringValue is None:
+            return None
+        elif lowerStringValue == 'http':
+            return FeatureFlagsConfigSchemeEnum.HTTP
+        elif lowerStringValue == 'https':
+            return FeatureFlagsConfigSchemeEnum.HTTPS
+        else:
+            return None
+
+    @classmethod
+    def valueAsString(cls, enumValue):
+        if enumValue is None:
+            return ''
+        elif enumValue == FeatureFlagsConfigSchemeEnum.HTTP:
+            return 'http'
+        elif enumValue == FeatureFlagsConfigSchemeEnum.HTTPS:
+            return 'https'
+        else:
+            return ''
+
+
+
